@@ -663,11 +663,17 @@ _refresh_background (Bubble* self)
 	}
 
 	// clear, render top-left part of shadow/background in scratch-surface
-    	cairo_scale (cr, 1.0f, 1.0f);
+    cairo_scale (cr, 1.0f, 1.0f);
 	cairo_set_operator (cr, CAIRO_OPERATOR_CLEAR);
 	cairo_paint (cr);
 	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 
+	GdkRGBA color;
+	gchar* color_string = NULL;
+    color_string = defaults_get_bubble_bg_color (d);
+	gdk_rgba_parse (&color, color_string);
+    g_free (color_string);
+	
 	if (priv->composited)
 	{
 		_draw_shadow (
@@ -689,16 +695,16 @@ _refresh_background (Bubble* self)
 		cairo_fill (cr);
 		cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 		cairo_set_source_rgba (cr,
-				       BUBBLE_BG_COLOR_R,
-				       BUBBLE_BG_COLOR_G,
-				       BUBBLE_BG_COLOR_B,
+				       0.75 * color.red,
+				       0.75 * color.green,
+				       0.75 * color.blue,
 				       BUBBLE_BG_COLOR_A);
 	}
 	else
 		cairo_set_source_rgb (cr,
-				      BUBBLE_BG_COLOR_R,
-				      BUBBLE_BG_COLOR_G,
-				      BUBBLE_BG_COLOR_B);
+				       0.75 * color.red,
+				       0.75 * color.green,
+				       0.75 * color.blue);
 
 	draw_round_rect (
 		cr,
