@@ -175,7 +175,6 @@ fallback_dialog_show (Defaults*    d,
 	dialog_info->sender = g_strdup(sender);
 
 	dialog = gtk_dialog_new ();
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	hbox = g_object_new (GTK_TYPE_HBOX,
 			     "spacing", gap,
@@ -268,6 +267,7 @@ fallback_dialog_show (Defaults*    d,
 				  "button-release-event",
 				  G_CALLBACK (handle_close),
 				  dialog);
+	gtk_widget_set_can_default(GTK_WIDGET(cancel), FALSE);
 
 	g_signal_connect (G_OBJECT (dialog),
 			  "response",
@@ -287,6 +287,7 @@ fallback_dialog_show (Defaults*    d,
 			  "button-release-event",
 			  G_CALLBACK (handle_response),
 			  dialog);
+	gtk_widget_set_can_default(GTK_WIDGET(ok), FALSE);
 
 	g_object_set_data (G_OBJECT (dialog),
 			   "_dialog_info",
